@@ -7,7 +7,10 @@ class Data:
 
     def __str__(self) -> str:
         from elma.models.data.data_serializer import data_to_json_str
-        return data_to_json_str(self)
+        return data_to_json_str(self)\
+            .replace("\"null\"", "null")\
+            .replace("\"[]\"", "[]")\
+            .replace("{}", "null")
 
     @staticmethod
     def from_json(json: dict):
