@@ -8,7 +8,7 @@ class StartProcess(DataSerializable):
     def __init__(self, context_vars: Data = Data(), process_name=None,
                  process_token: str = None, process_header_id: int = None) -> None:
         self.Context = context_vars
-        self.ProcessName = process_name
+        self.ProcessName = str(process_name)
         self.ProcessToken = process_token
         self.ProcessHeaderId = process_header_id
         super().__init__()
